import * as React from 'react';
import type { Map as MapboxMap, MapboxOptions, Marker as MapboxMarker, MarkerOptions, Popup as MapboxPopup, PopupOptions, AttributionControl as MapboxAttributionControl, FullscreenControl as MapboxFullscreenControl, GeolocateControl as MapboxGeolocateControl, NavigationControl as MapboxNavigationControl, ScaleControl as MapboxScaleControl } from 'mapbox-gl';
import { MapProps as _MapProps } from './components/map';
import { MarkerProps as _MarkerProps } from './components/marker';
import { PopupProps as _PopupProps } from './components/popup';
import { AttributionControlProps as _AttributionControlProps } from './components/attribution-control';
import { FullscreenControlProps as _FullscreenControlProps } from './components/fullscreen-control';
import { GeolocateControlProps as _GeolocateControlProps } from './components/geolocate-control';
import { NavigationControlProps as _NavigationControlProps } from './components/navigation-control';
import { ScaleControlProps as _ScaleControlProps } from './components/scale-control';
import type { MapRef as _MapRef } from './mapbox/create-ref';
import type * as events from './types/events';
export declare function useMap(): {
    [id: string]: _MapRef<MapboxMap>;
    current?: _MapRef<MapboxMap>;
};
export declare type MapProps = _MapProps<MapboxOptions, MapboxMap>;
export declare type MapRef = _MapRef<MapboxMap>;
export declare const Map: React.ForwardRefExoticComponent<{
    zoom?: number;
    bearing?: number;
    pitch?: number;
    maxZoom?: number;
    minZoom?: number;
    interactive?: boolean;
    minPitch?: number;
    maxPitch?: number;
    maxBounds?: import("mapbox-gl").LngLatBoundsLike;
    projection?: import("mapbox-gl").Projection;
    renderWorldCopies?: boolean;
    scrollZoom?: boolean | import("mapbox-gl").InteractiveOptions;
    boxZoom?: boolean;
    dragRotate?: boolean;
    dragPan?: boolean | import("mapbox-gl").DragPanOptions;
    keyboard?: boolean;
    doubleClickZoom?: boolean;
    touchZoomRotate?: boolean | import("mapbox-gl").InteractiveOptions;
    touchPitch?: boolean | import("mapbox-gl").InteractiveOptions;
    accessToken?: string;
    localIdeographFontFamily?: string;
    antialias?: boolean;
    attributionControl?: boolean;
    bearingSnap?: number;
    clickTolerance?: number;
    collectResourceTiming?: boolean;
    crossSourceCollisions?: boolean;
    cooperativeGestures?: boolean;
    customAttribution?: string | string[];
    hash?: string | boolean;
    fadeDuration?: number;
    failIfMajorPerformanceCaveat?: boolean;
    locale?: {
        [key: string]: string;
    };
    localFontFamily?: string;
    logoPosition?: "top-left" | "top-right" | "bottom-left" | "bottom-right";
    optimizeForTerrain?: boolean;
    preserveDrawingBuffer?: boolean;
    pitchWithRotate?: boolean;
    refreshExpiredTiles?: boolean;
    trackResize?: boolean;
    transformRequest?: import("mapbox-gl").TransformRequestFunction;
    maxTileCacheSize?: number;
    testMode?: boolean;
    worldview?: string;
} & Partial<import("./types/common").ViewState> & {
    mapboxAccessToken?: string;
    initialViewState?: Partial<import("./types/common").ViewState> & {
        bounds?: import("./types/common").LngLatBoundsLike;
        fitBoundsOptions?: {
            offset?: import("./types/common").PointLike;
            minZoom?: number;
            maxZoom?: number;
            padding?: number | import("./types/common").PaddingOptions;
        };
    };
    gl?: WebGLRenderingContext;
    viewState?: import("./types/common").ViewState & {
        width: number;
        height: number;
    };
    mapStyle?: string | import("@maplibre/maplibre-gl-style-spec").StyleSpecification | import("./types/common").ImmutableLike<import("@maplibre/maplibre-gl-style-spec").StyleSpecification>;
    styleDiffing?: boolean;
    fog?: import("./types/style-spec").Fog;
    light?: import("@maplibre/maplibre-gl-style-spec").LightSpecification;
    terrain?: import("@maplibre/maplibre-gl-style-spec").TerrainSpecification;
    interactiveLayerIds?: string[];
    cursor?: string;
    onMouseDown?: (e: events.MapLayerMouseEvent<MapboxMap>) => void;
    onMouseUp?: (e: events.MapLayerMouseEvent<MapboxMap>) => void;
    onMouseOver?: (e: events.MapLayerMouseEvent<MapboxMap>) => void;
    onMouseMove?: (e: events.MapLayerMouseEvent<MapboxMap>) => void;
    onClick?: (e: events.MapLayerMouseEvent<MapboxMap>) => void;
    onDblClick?: (e: events.MapLayerMouseEvent<MapboxMap>) => void;
    onMouseEnter?: (e: events.MapLayerMouseEvent<MapboxMap>) => void;
    onMouseLeave?: (e: events.MapLayerMouseEvent<MapboxMap>) => void;
    onMouseOut?: (e: events.MapLayerMouseEvent<MapboxMap>) => void;
    onContextMenu?: (e: events.MapLayerMouseEvent<MapboxMap>) => void;
    onTouchStart?: (e: events.MapLayerTouchEvent<MapboxMap>) => void;
    onTouchEnd?: (e: events.MapLayerTouchEvent<MapboxMap>) => void;
    onTouchMove?: (e: events.MapLayerTouchEvent<MapboxMap>) => void;
    onTouchCancel?: (e: events.MapLayerTouchEvent<MapboxMap>) => void;
    onMoveStart?: (e: events.ViewStateChangeEvent<MapboxMap>) => void;
    onMove?: (e: events.ViewStateChangeEvent<MapboxMap>) => void;
    onMoveEnd?: (e: events.ViewStateChangeEvent<MapboxMap>) => void;
    onDragStart?: (e: events.ViewStateChangeEvent<MapboxMap>) => void;
    onDrag?: (e: events.ViewStateChangeEvent<MapboxMap>) => void;
    onDragEnd?: (e: events.ViewStateChangeEvent<MapboxMap>) => void;
    onZoomStart?: (e: events.ViewStateChangeEvent<MapboxMap>) => void;
    onZoom?: (e: events.ViewStateChangeEvent<MapboxMap>) => void;
    onZoomEnd?: (e: events.ViewStateChangeEvent<MapboxMap>) => void;
    onRotateStart?: (e: events.ViewStateChangeEvent<MapboxMap>) => void;
    onRotate?: (e: events.ViewStateChangeEvent<MapboxMap>) => void;
    onRotateEnd?: (e: events.ViewStateChangeEvent<MapboxMap>) => void;
    onPitchStart?: (e: events.ViewStateChangeEvent<MapboxMap>) => void;
    onPitch?: (e: events.ViewStateChangeEvent<MapboxMap>) => void;
    onPitchEnd?: (e: events.ViewStateChangeEvent<MapboxMap>) => void;
    onWheel?: (e: events.MapWheelEvent<MapboxMap>) => void;
    onBoxZoomStart?: (e: events.MapBoxZoomEvent<MapboxMap>) => void;
    onBoxZoomEnd?: (e: events.MapBoxZoomEvent<MapboxMap>) => void;
    onBoxZoomCancel?: (e: events.MapBoxZoomEvent<MapboxMap>) => void;
    onResize?: (e: events.MapEvent<MapboxMap, undefined>) => void;
    onLoad?: (e: events.MapEvent<MapboxMap, undefined>) => void;
    onRender?: (e: events.MapEvent<MapboxMap, undefined>) => void;
    onIdle?: (e: events.MapEvent<MapboxMap, undefined>) => void;
    onError?: (e: events.ErrorEvent<MapboxMap>) => void;
    onRemove?: (e: events.MapEvent<MapboxMap, undefined>) => void;
    onData?: (e: events.MapStyleDataEvent<MapboxMap> | events.MapSourceDataEvent<MapboxMap>) => void;
    onStyleData?: (e: events.MapStyleDataEvent<MapboxMap>) => void;
    onSourceData?: (e: events.MapSourceDataEvent<MapboxMap>) => void;
} & import("./utils/set-globals").GlobalSettings & {
    mapLib?: import("./types/lib").MapLib<MapboxMap> | Promise<import("./types/lib").MapLib<MapboxMap>>;
    reuseMaps?: boolean;
    id?: string;
    style?: React.CSSProperties;
    children?: any;
} & React.RefAttributes<MapRef>>;
export declare type MarkerProps = _MarkerProps<MarkerOptions, MapboxMarker>;
export declare const Marker: (props: MarkerProps & React.RefAttributes<MapboxMarker>) => React.ReactElement | null;
export declare type PopupProps = _PopupProps<PopupOptions, MapboxPopup>;
export declare const Popup: (props: PopupProps & React.RefAttributes<MapboxPopup>) => React.ReactElement | null;
declare type AttributionControlOptions = ConstructorParameters<typeof MapboxAttributionControl>[0];
export declare type AttributionControlProps = _AttributionControlProps<AttributionControlOptions>;
export declare const AttributionControl: (props: AttributionControlProps) => React.ReactElement | null;
declare type FullscreenControlOptions = ConstructorParameters<typeof MapboxFullscreenControl>[0];
export declare type FullscreenControlProps = _FullscreenControlProps<FullscreenControlOptions>;
export declare const FullscreenControl: (props: FullscreenControlProps) => React.ReactElement | null;
declare type NavigationControlOptions = ConstructorParameters<typeof MapboxNavigationControl>[0];
export declare type NavigationControlProps = _NavigationControlProps<NavigationControlOptions>;
export declare const NavigationControl: (props: NavigationControlProps) => React.ReactElement | null;
declare type GeolocateControlOptions = ConstructorParameters<typeof MapboxGeolocateControl>[0];
export declare type GeolocateControlProps = _GeolocateControlProps<GeolocateControlOptions, MapboxGeolocateControl>;
export declare const GeolocateControl: (props: GeolocateControlProps & React.RefAttributes<MapboxGeolocateControl>) => React.ReactElement | null;
declare type ScaleControlOptions = ConstructorParameters<typeof MapboxScaleControl>[0];
export declare type ScaleControlProps = _ScaleControlProps<ScaleControlOptions>;
export declare const ScaleControl: (props: ScaleControlProps) => React.ReactElement | null;
export { default as Source } from './components/source';
export { default as Layer } from './components/layer';
export { default as useControl } from './components/use-control';
export { MapProvider } from './components/use-map';
export default Map;
export * from './types/public';
export type { SourceProps } from './components/source';
export type { LayerProps } from './components/layer';
export declare type MapEvent = events.MapEvent<MapboxMap>;
export declare type ErrorEvent = events.ErrorEvent<MapboxMap>;
export declare type MapStyleDataEvent = events.MapStyleDataEvent<MapboxMap>;
export declare type MapSourceDataEvent = events.MapSourceDataEvent<MapboxMap>;
export declare type MapMouseEvent = events.MapMouseEvent<MapboxMap>;
export declare type MapLayerMouseEvent = events.MapLayerMouseEvent<MapboxMap>;
export declare type MapTouchEvent = events.MapTouchEvent<MapboxMap>;
export declare type MapLayerTouchEvent = events.MapLayerTouchEvent<MapboxMap>;
export declare type MapWheelEvent = events.MapWheelEvent<MapboxMap>;
export declare type MapBoxZoomEvent = events.MapBoxZoomEvent<MapboxMap>;
export declare type ViewStateChangeEvent = events.ViewStateChangeEvent<MapboxMap>;
export declare type PopupEvent = events.PopupEvent<MapboxPopup>;
export declare type MarkerEvent = events.MarkerEvent<MapboxMarker>;
export declare type MarkerDragEvent = events.MarkerDragEvent<MapboxMarker>;
export declare type GeolocateEvent = events.GeolocateEvent<MapboxGeolocateControl>;
export declare type GeolocateResultEvent = events.GeolocateResultEvent<MapboxGeolocateControl>;
export declare type GeolocateErrorEvent = events.GeolocateErrorEvent<MapboxGeolocateControl>;
